# Nostr-ChatBot

Make Nostr ChatBot from python

## Install

> pip install nostr-chatbot

## Example

See [https://github.com/wannaphong/nostr-chatbot/tree/main/example](https://github.com/wannaphong/nostr-chatbot/tree/main/example)